<?php
/**
 * Luxeritas WordPress Theme - free/libre wordpress platform
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * @copyright Copyright (C) 2015 Thought is free.
 * @license http://www.gnu.org/licenses/gpl-2.0.html GPL v2 or later
 * @author LunaNuko
 * @link https://thk.kanzae.net/
 * @translators rakeem( http://rakeem.jp/ )
 */

class thk_custom_image_sizes {
	public function __construct() {
	}

	public static function custom_image_sizes( $choose = true ) {
		$image_sizes = self::regist_image_sizes();

		foreach( $image_sizes as $slug => $size ) {
			if( has_image_size( $slug ) === false ) {
				add_image_size( $slug, $size['width'], $size['height'], $size['crop'] );
			}
		}

		if( $choose != false ) {
			add_action( 'image_size_names_choose', function( $size_names ) use( $image_sizes ) {
				$custom_sizes = get_intermediate_image_sizes();
				foreach( $custom_sizes as $val ) {
					if( isset( $image_sizes[$val]['selectable'] ) && $image_sizes[$val]['selectable'] ) {
						if( !isset( $size_names[$val] ) ) {
							$size_names[$val] = $image_sizes[$val]['name'];
						}
					}
				}
				return $size_names;
			});
		}
	}

	public static function regist_image_sizes() {
		$custom_image_sizes = array(
			'thumb75' => array(
				'name'       => __( 'Micro thumbnail', 'luxeritas' ),
				'width'      => 75,
				'height'     => 75,
				'crop'       => true,
				'selectable' => false
			),
			'thumb100' => array(
				'name'       => __( 'Small thumbnail', 'luxeritas' ),
				'width'      => 100,
				'height'     => 100,
				'crop'       => true,
				'selectable' => false
			),
			'thumb320' => array(
				'name'       => __( 'Horizontal thumbnail', 'luxeritas' ),	// 選択肢のラベル名
				'width'      => 320,         	// 最大画像幅
				'height'     => 180,         	// 最大画像高さ
				'crop'       => true,        	// 切り抜きを行うかどうか
				'selectable' => true         	// 選択肢に含めるかどうか
			),
			'thumb530' => array(
				'name'       => __( 'Small size', 'luxeritas' ) . '(' . __( 'Side bar with 336 px', 'luxeritas' ) . ')',
				'width'      => 530,
				'height'     => 530,
				'crop'       => false,
				'selectable' => true
			),
			'thumb565' => array(
				'name'       => __( 'Small size', 'luxeritas' ) . '(' . __( 'Side bar with 300 px', 'luxeritas' ) . ')',
				'width'      => 565,
				'height'     => 565,
				'crop'       => false,
				'selectable' => true
			),
			'thumb710' => array(
				'name'       => __( 'Large size', 'luxeritas' ) . '(' . __( 'Side bar with 336 px', 'luxeritas' ) . ')',
				'width'      => 710,
				'height'     => 710,
				'crop'       => false,
				'selectable' => true
			),
			'thumb725' => array(
				'name'       => __( 'Large size', 'luxeritas' ) . '(' . __( 'Side bar with 300 px', 'luxeritas' ) . ')',
				'width'      => 725,
				'height'     => 725,
				'crop'       => false,
				'selectable' => true
			),
		);

		$w = (int)get_theme_mod( 'thumbnail_width', 150 );
		$h = (int)get_theme_mod( 'thumbnail_height', 150 );
		if( $w >= 0 && $h >= 0 ) {
			if( $w !== 150 || $h !== 150 ) {
				$custom_image_sizes += array(
					'thumb' . $w . 'x' . $h => array(
						'name'       => __( 'User thumbnail', 'luxeritas' ),
						'width'      => $w,
						'height'     => $h,
						'crop'       => true,
						'selectable' => true
					),
				);

				$ws = (int)ceil( $w * 0.666 );
				$hs = (int)ceil( $h * 0.666 );

				if( $ws >= 0 && $hs >= 0 ) {
					$custom_image_sizes += array(
						'thumb' . $ws . 'x' . $hs => array(
							'name'       => __( 'User thumbnail small', 'luxeritas' ),
							'width'      => $ws,
							'height'     => $hs,
							'crop'       => true,
							'selectable' => false
						),
					);
				}
			}
		}
		return $custom_image_sizes;
	}
}
